# debandshit, a collection of wrappers and functions for debanding

This repository is intended to be a maintained version of `debandshit` until [Z4STIN](https://github.com/kgrabs) continues maintaining it himself.

The original v0.3.0 of `debandshit.py` that this is built on from can be found [here](https://pastebin.com/NGFBhCCn).

For further support, drop by `#debandshit` in the [IEW Discord server](https://discord.gg/qxTxVJGtst).

## How to install

If you have the old `debandshit.py` module,
remove that from your system first.

Install `debandshit` with the following command:

```sh
$ pip install vs-debandshit
```

## Dependencies

debandshit depends on the following third-party scripts:

- [mvsfunc](https://github.com/HomeOfVapourSynthEvolution/mvsfunc)
- [vsutil](https://pypi.org/project/vsutil/)

And the following VapourSynth libraries:

- [fmtconv](https://github.com/EleonoreMizo/fmtconv)
- [vs-placebo](https://github.com/Lypheo/vs-placebo)
